@@ -20,10 +20,8 @@ def getAwsInstanceDetails(config, authentication_token, account_id, host, log, d
                             'host': 'host-123'}
     
     metadata_token_url = config.get('aws_metadata_service_token_url', None)
-    aws_token = _fetch_aws_metadata_token(metadata_token_url, log=log)
-
     locator_url = config['aws_instance_id_locator_url']
-    instance_id = getAwsInstanceId(locator_url, log, token=aws_token)
+    instance_id = getAwsInstanceId(locator_url, log, metadata_token_url=metadata_token_url)
     if instance_id and authentication_token:
         instance_details = {'cloud_provider': 'AWS', 'instance_id': instance_id,
                             'authentication_token': authentication_token,
@@ -141,14 +139,21 @@ def init__configuration(config, cloud_provider, debug=False):
     return instance_details
 
 
-def getAwsInstanceId(locator_url, log, token=None):
+def getAwsInstanceId(locator_url, log, metadata_token_url=None):
     response = None
     if locator_url:
         if locator_url.startswith("http://"):
+            aws_token = None
+            
+            if metadata_token_url:
+                aws_token = _fetch_aws_metadata_token(metadata_token_url, log=log)
+            else:
+                log.error("Url for fetching aws metadata token is None in config")
+
             headers = {}
 
-            if token:
-                headers['x-aws-ec2-metadata-token'] = token
+            if aws_token:
+                headers['x-aws-ec2-metadata-token'] = aws_token
             else:
                 log.warn("Failed to retrieve aws token, using IMDSv1 instead")
 
@@ -168,17 +173,15 @@ def getAwsInstanceId(locator_url, log, token=None):
 
 
 def _fetch_aws_metadata_token(token_url, log=logging.getLogger('spotinst-agent'), token_ttl=21600):
+    headers = {
+        'x-aws-ec2-metadata-token-ttl-seconds': str(token_ttl),
+    }
+
+    token_response = safe_put_simple_url(token_url, log, headers)
     response = None
 
-    if token_url:
-        headers = {
-            'x-aws-ec2-metadata-token-ttl-seconds': str(token_ttl),
-        }
-
-        token_response = safe_put_simple_url(token_url, log, headers)
-
-        if token_response:
-            response = str(token_response)
+    if token_response:
+        response = str(token_response)
 
     return response
 
